# Enhancing Adaptive Behavioral Interventions with LLM Inference from Participant-Described States

This repository contains the official implementation for **LLM4TS** and **StepCountJITAI+LLM**, from the paper: **Enhancing Adaptive Behavioral Interventions with LLM Inference from Participant-Described States**, Karine Karine and Benjamin M. Marlin, 2025.

This paper was accepted at MLHC 2025.

+ arXiv link: https://arxiv.org/abs/2507.03871

+ paper link: https://github.com/reml-lab/llm4ts/tree/main/LLM4TS_paper.pdf

+ poster link: https://github.com/reml-lab/llm4ts/tree/main/LLM4TS_poster.pdf

## Examples

See the [examples](https://github.com/reml-lab/llm4ts/tree/main/examples) directory for a list of examples that can be run locally or launched in Google Colab.

For example:

+ [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/reml-lab/llm4ts/blob/main/examples/LLM4TS_quickstart.ipynb)  LLM4TS and StepCountJITAI+LLM QuickStart


## Citing this paper

```
@inproceedings{LLM4TS2025, 
title = {Enhancing Adaptive Behavioral Interventions with LLM Inference from Participant-Described States},
author={Karine Karine and Benjamin M. Marlin},
booktitle = {Machine Learning for Healthcare (MLHC) 2025,
year = {2025},
}
```
